@@ -1,4 +1,7 @@
-from . import PCF8591 as ADC
+if __package__:
+	from . import PCF8591 as ADC
+else:
+	import PCF8591 as ADC
 import time
 
 RUNNING = True
